import React, { useEffect } from 'react'
import { io } from 'socket.io-client'

import { Box } from '@chakra-ui/react'
import { Canvas } from 'react-three-fiber'

import MenuOverlay from './MenuOverlay'
import Error from './Error'
import Scene from '../3d'

import useStore from '../store'

const Museo: React.FC = () => {
  const setSocket = useStore((state) => state.setSocket)
  const setError = useStore((state) => state.setError)
  const error = useStore((state) => state.error)

  useEffect(() => {
    const socket = io()
    setSocket(socket)

    socket.on('disconnect', () => setError('SOCKET'))

    return () => {
      socket.close()
      setSocket(null)
    }
  }, [])

  return (
    <Box w="100vw" h="100vh">
      {error ? (
        <Error />
      ) : (
        <>
          <MenuOverlay />
          <Canvas colorManagement>
            <Scene />
          </Canvas>
        </>
      )}
    </Box>
  )
}

export default Museo
